@@ -233,7 +233,7 @@ def populateEnvToSettings(keys, settingsDict, setter=None, evalKeys=None):
             
     return setKeys
     
-def attachSettings(settingsDict, , warns=False, printDetail=True)):
+def attachSettings(settingsDict, warns=False, printDetail=True):
     """
     Attach default settings to settings.py.
     It must be called in settings by passing locals().
@@ -502,7 +502,7 @@ def attachSettings(settingsDict, , warns=False, printDetail=True)):
             'debug_file': {
                 'level': 'DEBUG',
                 'class': 'logging.FileHandler',
-                'filename': os.path.join(BASE_DIR, 'debug.log'),
+                'filename': os.path.join(settingsDict['BASE_DIR'], 'debug.log'),
             },        
         })
         loggingDefaults['LOGGING']['loggers'].update({
@@ -868,7 +868,7 @@ def attachIunoUrls(settings, urlpatterns):
     urlpatterns += patterns('',
         (r'^i18n/', include('django.conf.urls.i18n')),
     )
-    
+
     if settings.DEBUG == False:
         urlpatterns += patterns('',
             url(r'^media/(?P<path>.*)$', 'django.views.static.serve', {
@@ -876,21 +876,15 @@ def attachIunoUrls(settings, urlpatterns):
             })
     )
 
-# Attach debug_tool_bar Urls
-def attachDebugToolBarUrls(settings, urlpatterns):
-    """
-    Attach debug_tool_bar related urlpatterns.
-    It must be called in urls.py by passing urlpatterns.
-
-    @param settings Django project's settings module.
-    @param urlpatterns urlpatterns in urls.py.
-    """
-    from django.conf.urls import url, include, patterns
-
-    if settings.DEBUG:
-        urlpatterns += patterns('',
-            url(r'^__debug__/', include(debug_toolbar.urls)),
-        )
+    try:
+        import debug_toolbar
+    except:
+        pass
+    else:
+        if settings.DEBUG:
+            urlpatterns += patterns('',
+                url(r'^__debug__/', include(debug_toolbar.urls)),
+            )
 
 # detect Server mode
 def detectServerMode(settingsDict):
