@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9840 2017-04-02 02:58:40Z David $
+# $Id: __init__.py 9889 2017-04-22 14:24:50Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-04-02 10:58:40 +0800 (Sun, 02 Apr 2017) $
-# $Revision: 9840 $
+# $Date: 2017-04-22 22:24:50 +0800 (Sat, 22 Apr 2017) $
+# $Revision: 9889 $
 
 import os
 import sys
@@ -218,8 +218,7 @@ def attachShopURLs(settings, urlpatterns):
     from oscar.app import application as shop
 
     urlpatterns += patterns('',
-        (r'^i18n/', include('django.conf.urls.i18n')),
-        (r'', include(shop.urls)),
+        (r'^shop/', include(shop.urls)),
     )
 
 def attachPaypalURLs(settings, urlpatterns):
